from django.contrib import admin
from django.utils.html import format_html
from django.utils.translation import ugettext_lazy as _

from ..models.notification import Notification

class NotificationAdmin(admin.ModelAdmin):
    list_display = ('notification_id', 'internal_name', 'message_title', 'active' )
    fields = ('internal_name', 'internal_description', 'message_title', 'message_body', 'image_url', 'get_image_preview', 'schedule_date', 'schedule_hook', 'schedule_sql', 'active' )
    list_editable = ('internal_name', 'active')
    readonly_fields = ("get_image_preview",)

    def get_image_preview(self, obj):
        image_url = '/media/' + str(obj.image_url)
        if obj.pk:
            return format_html('<img src="{url}" title="{url}" width="30%" height="30%"/> ' \
                               .format(url=image_url))

    get_image_preview.short_description = _("Image Preview")

    def clone_notification(self, request, queryset):
        for notif in queryset:
            notif.pk = None
            notif.internal_name = notif.internal_name + "_copy"
            notif.save()

    clone_notification.short_description = "Clone the selected notification"

    actions = [clone_notification]




admin.site.register(Notification, NotificationAdmin)
admin.autodiscover()